@@ -5,4 +5,4 @@ def test_test():
     """
     Tests that testing works
     """
-    assert (True)
+    assert True
